<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-cpf',
'0_langue' => 'Kr&eacute;ol r&eacute;nyon&eacute; [cpf]',
'0_liste' => 'spip-cpf@rezo.net',
'0_mainteneur' => 'pascale@rezo.net',

// A
'access_interface_graphique' => 'Artoun si lint&egrave;rfas grafik konpl&eacute;',
'access_mode_texte' => 'Afis lint&egrave;rfas t&egrave;ks sinp',
'admin_debug' => 'debug',
'admin_modifier_article' => 'Sanz lartik-la',
'admin_modifier_auteur' => 'Sanz linformasyon lot&egrave;r',
'admin_modifier_breve' => 'Sanz tit-nouv&egrave;l-la',
'admin_modifier_mot' => 'Sanz molakl&eacute;-la',
'admin_modifier_rubrique' => 'Sanz rubrik-la',
'admin_recalculer' => 'Arkalkil pazw&egrave;b-la',
'afficher_trad' => 'Afich\' bann tradiksyon',
'alerte_maj_impossible' => '<b>Tansyon&nbsp;!</b> Larnouv&egrave;lman labazdodn&eacute; SQL zizka lo v&egrave;rsyon @version@ l&eacute; pa posib, peut-&ecirc;tre &agrave; cause d\'un probl&egrave;me de droit de modification sur la base de donn&eacute;es. Veuillez contacter votre h&eacute;bergeur.', # MODIF
'alerte_modif_info_concourante' => 'ATTENTION : Cette information a &eacute;t&eacute; modifi&eacute; par ailleurs. La valeur actuelle est&nbsp;:', # MODIF
'analyse_xml' => 'Analiz XML',
'annuler' => 'Anil\'',
'antispam_champ_vide' => 'L&eacute;s karo-la vide&nbsp;:',
'articles_recents' => 'Bann zartik li l&eacute; nouvo',
'avis_archive_incorrect' => 'Lo fisy&eacute; arsiv l&eacute; pwinn inn fisy&eacute; SPIP',
'avis_archive_invalide' => 'Lo fisy&eacute; arsiv i giny pa mars&eacute;',
'avis_attention' => 'TANSYON PANGAR&nbsp;!',
'avis_champ_incorrect_type_objet' => 'Non d\'karo-la l&eacute; fo @name@ pou inn siz&eacute; lo tip-la minm : @type@',
'avis_colonne_inexistante' => 'Nana pwinn kolonn-la : @col@ ',
'avis_echec_syndication_01' => 'Sindikasyon-la la giny pa mars&eacute; : l&eacute; inposib lir lo "backend" ou la don&eacute;, oubyensa li n&eacute;na pwind zartik propoz&eacute;.',
'avis_echec_syndication_02' => 'Sindikasyon-la, la giny pa mars&eacute; : lariv&eacute; dann "backend" sit-la l&eacute; inposib.',
'avis_erreur' => 'Kanard : g&egrave;t anba.',
'avis_erreur_connexion' => 'Ast&egrave;r n&eacute;na inn kanard &egrave;k lakostaz.

',
'avis_erreur_cookie' => 'N&eacute;na in larlik &egrave;k lo gatomakro (kouki)',
'avis_erreur_fonction_contexte' => 'Ast&egrave;r n&eacute;na inn kanard dann program-la. Fonksyon-la, ou dwa pa ap&egrave;l ali dann kont&egrave;ks-la.

', # MODIF
'avis_erreur_mysql' => 'N&eacute;na inn kanard SQL', # MODIF
'avis_erreur_sauvegarde' => 'Ast&egrave;r n&eacute;na inn kanard &egrave;k la sovgard (@type@ @id_objet@) !',
'avis_erreur_visiteur' => 'Kanard &eacute;k laks&eacute; priv&eacute;',

// B
'barre_a_accent_grave' => 'Pou m&egrave;t in A &egrave;k son laksan grav an mazizkil',
'barre_aide' => 'Pou ans&egrave;rv bann r&eacute;diyon-limprimri andan lapr&eacute;zantasyon dout paz',
'barre_e_accent_aigu' => 'Pou m&egrave; in E &egrave;k son laksan &eacute;gi an mazizkil',
'barre_eo' => 'Pou m&egrave;t in E andan O',
'barre_eo_maj' => 'Pou m&egrave;t in E andan O an mazizkil',
'barre_euro' => 'M&egrave;t lo sinbol &euro;',
'barre_gras' => 'Pou &eacute;kri {{an gro}}',
'barre_guillemets' => 'Pou m&egrave;t bann &laquo; giym&eacute; frans&eacute; &raquo;',
'barre_guillemets_simples' => 'Pou m&egrave; bann „giym&eacute;“',
'barre_intertitre' => 'M&egrave;t sa-la kom in {{{lint&egrave;rtitr}}}',
'barre_italic' => 'M&egrave;t sa-la an {litalik}',
'barre_lien' => 'M&egrave;t sa-la kom in [gatir w&egrave;b->http://...]',
'barre_lien_input' => 'M&egrave;rsi  indil ladr&egrave;s out gatir w&egrave;b (kom in ladr&egrave;s http://www.monsite/com ou sinpman &egrave;k lo nim&eacute;ro in lartik sit-la minm.',
'barre_note' => 'Po sanz&eacute; an [[not anba lapaz]]',
'barre_paragraphe' => 'Kr&eacute; in paragraf',
'barre_quote' => '<quote>Sit inn mod&eacute;kri</quote>',
'bouton_ajouter_document' => 'AZOUT INN DOKIMAN', # MODIF
'bouton_ajouter_image' => 'AZOUT INN ZIMAZ', # MODIF
'bouton_ajouter_image_document' => 'Azout\' in zimaz ou in dokiman',
'bouton_changer' => 'Sanz',
'bouton_chercher' => 'Rod',
'bouton_choisir' => 'Swazi',
'bouton_download' => 'Trap&eacute;',
'bouton_enregistrer' => 'Anrozistr&eacute;',
'bouton_radio_desactiver_messagerie_interne' => 'D&eacute;gr&egrave;n lakazmod&eacute;kri',
'bouton_radio_envoi_annonces' => 'Anvwa bann zanons l&eacute;ditoryal. ',
'bouton_radio_non_envoi_annonces' => 'Anp&egrave;s anvway&eacute; bann zanons ',
'bouton_radio_non_envoi_liste_nouveautes' => 'Anp&egrave;s anvway&eacute; lalist bann nouv&egrave;lt&eacute;',
'bouton_recharger_page' => 'rosarz lapazw&egrave;b-la ',
'bouton_telecharger' => 'T&eacute;l&eacute;sarz',
'bouton_valider' => 'Konfirm',

// C
'cal_apresmidi' => 'apr&eacute;midi',
'cal_jour_entier' => 'jou konpl&eacute;',
'cal_matin' => 'matin',
'cal_par_jour' => 'kalandrye pa jou',
'cal_par_mois' => 'kalandrye pa mwa',
'cal_par_semaine' => 'kalandrye pa sem&egrave;n',
'choix_couleur_interface' => 'Koul&egrave;r',
'choix_interface' => 'soizi lint&egrave;rfas',
'colonne' => 'Kolonn',
'confirm_changer_statut' => 'Pangar, ou la domann po sanz lo statu z&eacute;l&eacute;man-la. L&eacute; byin sertin y v&eacute; sanz a li ?',
'correcte' => 'kor&egrave;k',

// D
'date_aujourdhui' => 'zordi',
'date_avant_jc' => 'avan J.C.',
'date_dans' => 'dann @delai@',
'date_de_mois_1' => '@j@ @nommois@',
'date_de_mois_10' => '@j@ @nommois@',
'date_de_mois_11' => '@j@ @nommois@',
'date_de_mois_12' => '@j@ @nommois@',
'date_de_mois_2' => '@j@ @nommois@',
'date_de_mois_3' => '@j@ @nommois@',
'date_de_mois_4' => '@j@ @nommois@',
'date_de_mois_5' => '@j@ @nommois@',
'date_de_mois_6' => '@j@ @nommois@',
'date_de_mois_7' => '@j@ @nommois@',
'date_de_mois_8' => '@j@ @nommois@',
'date_de_mois_9' => '@j@ @nommois@',
'date_demain' => 'domin',
'date_fmt_heures_minutes' => '@h@&egrave;r@m@min',
'date_fmt_jour_heure' => '@jour@ a @heure@',
'date_fmt_jour_mois' => '@jour@ @nommois@',
'date_fmt_jour_mois_annee' => '@jour@ @nommois@ @annee@',
'date_fmt_mois_annee' => '@nommois@ @annee@',
'date_fmt_nomjour_date' => 'lo @nomjour@ @date@',
'date_heures' => '&egrave;r',
'date_hier' => 'y&egrave;r',
'date_il_y_a' => 'n&eacute;na @delai@',
'date_jnum1' => '1',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'dimans',
'date_jour_1_abbr' => 'dim.',
'date_jour_1_initiale' => 'd.',
'date_jour_2' => 'lindi',
'date_jour_2_abbr' => 'lin.',
'date_jour_2_initiale' => 'l.',
'date_jour_3' => 'mardi',
'date_jour_3_abbr' => 'mar.',
'date_jour_3_initiale' => 'm.',
'date_jour_4' => 'm&egrave;rkrodi',
'date_jour_4_abbr' => 'm&egrave;r.',
'date_jour_4_initiale' => 'm.',
'date_jour_5' => 'zedi',
'date_jour_5_abbr' => 'ze.',
'date_jour_5_initiale' => 'z.',
'date_jour_6' => 'vandrodi',
'date_jour_6_abbr' => 'van.',
'date_jour_6_initiale' => 'v.',
'date_jour_7' => 'samdi',
'date_jour_7_abbr' => 'sam.',
'date_jour_7_initiale' => 's.',
'date_jours' => 'bann zor',
'date_minutes' => 'minite',
'date_mois' => 'mwa',
'date_mois_1' => 'zanvi&eacute;',
'date_mois_10' => 'octob',
'date_mois_11' => 'novanm',
'date_mois_12' => 'd&eacute;sanm',
'date_mois_2' => 'f&eacute;vri&eacute;',
'date_mois_3' => 'mars',
'date_mois_4' => 'avril',
'date_mois_5' => 'm&eacute;',
'date_mois_6' => 'zwin',
'date_mois_7' => 'zwiy&eacute;',
'date_mois_8' => 'out',
'date_mois_9' => 's&eacute;ptanm',
'date_saison_1' => 'liv&egrave;rnaz an Frans - d&eacute;bu la grands&eacute;zon la R&eacute;inyon  ',
'date_saison_2' => 'printan frans&eacute; - find la grands&eacute;zon /d&eacute;bud s&eacute;son s&egrave;k la R&eacute;inyon',
'date_saison_3' => '&eacute;t&eacute; frans&eacute; - s&eacute;zon s&egrave;k la R&eacute;inyon',
'date_saison_4' => 'otonn an Frans - find s&eacute;zon s&egrave;k / d&eacute;bu dla grands&eacute;zon la R&eacute;inyon',
'date_secondes' => 'secondes', # NEW
'date_semaines' => 'sem&egrave;n',
'date_un_mois' => 'mois', # NEW
'date_une_heure' => 'heure', # NEW
'date_une_minute' => 'minute', # NEW
'date_une_seconde' => 'seconde', # NEW
'date_une_semaine' => 'semaine', # NEW
'dirs_commencer' => 'pou komans fransv&eacute;rit&eacute; linstalasyon ',
'dirs_preliminaire' => 'Dabor : <b> R&egrave;g out bann drwa-laks&eacute;</b>',
'dirs_probleme_droits' => 'Ast&egrave;r, n&eacute;na inn larlik &egrave;k out bann drwa-laks&eacute;',
'dirs_repertoires_absents' => '<b>L&eacute; pa posib giny bann r&eacute;p&egrave;rtwar-la&nbsp;: <ul>@bad_dirs@.</ul> </b>
  <p>Ni pans n&eacute;na inn larlik &egrave;k l&eacute;kritir bann l&egrave;t maziskil o miniskil
  Ogad byin n&eacute;na okinn diskord ant bann zot maziskil o miniskil andann bann r&eacute;p&egrave;rtwar &eacute; sak l&eacute; afis&eacute;
  anl&egrave;r ; si ou trouv i l&eacute; pa par&egrave;y, ardonn inn ot non bann r&eacute;p&egrave;rtwar-la sanm out lozisy&egrave;l FTP. Komsa lo larlik i sra pou aranz&eacute;.
  <p>Kank ou lora fini ou sra kav ', # MODIF
'dirs_repertoires_suivants' => '<b>Bann r&eacute;pertwar-la l&eacute; pa ouv&egrave;r pou l&eacute;ktritir&nbsp;: <ul>@bad_dirs@.</ul> </b>


<p> Anserv out kliyan FTP, pou r&egrave;g bann drwa-lakostaz sir sakin


 r&eacute;pertwar-la. Lo guid linstalasyon i esplik aou, &egrave;k tout bann d&eacute;tay itil, kouk sa ou dwa f&egrave;r pou f&eacute; zw&eacute; bann drwa-la.


<p>Kank ou lora fini,i sra kav', # MODIF
'double_occurrence' => 'D&eacute; lokirans', # MODIF

// E
'en_cours' => 'en cours', # NEW
'entree_dimensions' => 'Kouk sa l&eacute; gran&nbsp;:',
'entree_titre_document' => 'Lo non lo dokiman&nbsp;:',
'entree_titre_image' => 'Lo nond limaz&nbsp;:',
'envoi_via_le_site' => 'Envwa samn lo sit',
'erreur' => 'Kanard',
'erreur_balise_non_fermee' => 'derny&eacute; baliz l&eacute; pa ferm&eacute; :',
'erreur_texte' => 'kanard(s)',
'etape' => '&Eacute;tape', # NEW

// F
'fichier_introuvable' => 'Fisy&eacute;-la @fichier@ ni pa kav trouv ali',
'form_auteur_confirmation' => 'Confirmez votre adresse email', # NEW
'form_auteur_email_modifie' => 'Votre adresse email a &eacute;t&eacute; modifi&eacute;e.', # NEW
'form_auteur_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre adresse mail.', # NEW
'form_auteur_mail_confirmation' => 'Bonjour,

Vous avez demand&eacute; &agrave; changer votre adresse email.
Pour confirmer votre nouvelle adresse, il suffit de vous connecter &agrave;
l\'adresse ci-dessous (dans le cas contraire, votre demande
sera ignor&eacute;e) :

    @url@
', # NEW
'form_deja_inscrit' => 'Ou l&eacute; d&eacute;za inskri.',
'form_email_non_valide' => 'Out ladr&egrave;s im&egrave;l la pa mars&eacute;.',
'form_forum_access_refuse' => 'Ou n&eacute;na plid drwa pou akost dann sitw&egrave;b-la.',
'form_forum_bonjour' => 'Ot&eacute; @nom@,,',
'form_forum_email_deja_enregistre' => 'Ladr&egrave;s im&egrave;l-la l&eacute; d&eacute;za anrozistr&eacute; : ou  p&eacute; anserv modpas sa-minm sak nana labitid.',
'form_forum_identifiant_mail' => 'Inn nouvo kod-lidentit&eacute; la finn d&egrave;t anvway&eacute; dann out kazim&egrave;l.',
'form_forum_identifiants' => 'Out bann kod-lidantit&eacute;',
'form_forum_indiquer_nom_email' => 'M&egrave;t isi out non &egrave;k ladr&egrave;s im&egrave;l. out kod-lidantit&eacute; li sava ariv tal&egrave;r dann out kazim&egrave;l.',
'form_forum_login' => 'Nondkod :',
'form_forum_message_auto' => '(sa l&eacute; inn mod&eacute;kri otomatik)',
'form_forum_pass' => 'modpas :',
'form_forum_probleme_mail' => 'Ast&egrave;r, nana inn larlik &egrave;k out im&egrave;l&nbsp;: lo kod-lidantit&eacute; i giny pa &egrave;t anvway&eacute;.',
'form_forum_voici1' => 'Ala out bann kod-lidantit&eacute; pou m&egrave;t ansanm ek vi lo sit"@nom_site_spip@" (@adresse_site@) :',
'form_forum_voici2' => 'Ala out bann kod-lidantit&eacute; pou ou i propoz bann zartik si lo sitw&egrave;b "@nom_site_spip@" (@adresse_login@) :',
'form_indiquer_email' => 'Mersi inskri out ladr&egrave;s im&egrave;l.',
'form_indiquer_nom' => 'Mersi m&egrave;t isi out non.',
'form_indiquer_nom_site' => 'Mersi m&egrave;t isi lo non out sitw&egrave;b.',
'form_pet_adresse_site' => 'Ladr&egrave;s out sitw&egrave;b',
'form_pet_aucune_signature' => 'Ast&egrave;r, nana pwinn sinyatir &egrave;k kod la-minm...',
'form_pet_confirmation' => 'Mersi konfirm t&egrave;rla out sinyatir :',
'form_pet_deja_enregistre' => 'Sitw&egrave;b-la l&eacute; d&eacute;za anrozistr&eacute;',
'form_pet_deja_signe' => 'Ou la d&eacute;za finn siny&eacute; lo t&egrave;ks-la.',
'form_pet_envoi_mail_confirmation' => 'Inn lim&egrave;l pou konfirm&eacute; la finn d&egrave;t anvway&eacute; aou. Li donn aou inn ladr&egrave;s sitw&egrave;b. L&eacute; n&eacute;s&eacute;s&egrave;r ou sava bat-kar&eacute; sir lo sit-la pou konfirm vr&eacute;man out sinyatir.', # MODIF
'form_pet_mail_confirmation' => 'Ot&eacute;,

Ou la domman siny&eacute; lo filsinyatir-la :
@titre@.

Ou la don&eacute; bann rans&eacute;ynman  swivan :
    Nom: @nom_email@
    Site: @nom_site@ - @url_site@

PANGAR...

Pou konfirm out sinyatir-la, i fo s&egrave;lman akost ladr&egrave;s anba (si l&eacute; pa f&eacute;, sitw&egrave;b-la i sava pa antyen kon out doman) :
    @url@

Mersi aou m&egrave;t ansanm isi
',
'form_pet_message_commentaire' => 'Inn mod&eacute;kri, inn ti lavi, inn komant&egrave;r&nbsp;?',
'form_pet_nom_site2' => '<b>Lo non out sitw&egrave;b ',
'form_pet_probleme_liens' => 'Arpran out\' m&egrave;zaz pou siprim bann gatiraz.',
'form_pet_probleme_technique' => 'Ast&egrave;r, nana inn larlik &egrave;k lat&eacute;knik : bann sinyatir l&eacute; bar&eacute; pou inn moman.',
'form_pet_signature_pasprise' => 'L&eacute; pa posib antyen pa out sinyatir.',
'form_pet_signature_validee' => 'Out sinyatir l&eacute; konfirm&eacute;. Mersi aou&nbsp;!',
'form_pet_site_deja_enregistre' => 'Sitw&egrave;b-la la d&eacute;za finn d&egrave;t anrozistr&eacute;',
'form_pet_url_invalide' => 'Ladr&egrave;s URL ou la finn don&eacute; l&eacute; pa kor&egrave;k.',
'form_pet_votre_email' => 'Out ladr&egrave;s im&egrave;l',
'form_pet_votre_nom' => 'Out vr&eacute;non ou ti-non-gat&eacute;',
'form_pet_votre_site' => 'Si out n&eacute;na out prop sitw&egrave;b, i p&eacute; m&egrave;t ali anba t&egrave;rla :',
'form_prop_confirmer_envoi' => 'Konfirm lanvwa',
'form_prop_description' => 'Kosa i l&eacute;/arkont son lavi',
'form_prop_enregistre' => 'Out kontribusyon l&eacute; byen ariv&eacute;. Li sra disponib an liyn apr&eacute; lakonfirmasyon innd&eacute; responsab lo sit.',
'form_prop_envoyer' => 'Anvwa inn mod&eacute;kri',
'form_prop_indiquer_email' => 'Mersi m&egrave;t inn ladr&egrave;s im&egrave;l sak i mars',
'form_prop_indiquer_nom_site' => 'Mersi m&egrave;t t&egrave;rla lo non lo sitw&egrave;b',
'form_prop_indiquer_sujet' => 'Mersi indik inn siz&eacute;',
'form_prop_message_envoye' => 'Out mod&eacute;kri la finn d&egrave;t anvway&eacute;',
'form_prop_nom_site' => 'Non lo sitw&egrave;b',
'form_prop_non_enregistre' => 'Out kontribusyion l&eacute; pa anrozistr&eacute;',
'form_prop_sujet' => 'Siz&eacute;',
'form_prop_url_site' => 'Ladr&egrave;s (URL) lo sitw&egrave;b',
'forum_acces_refuse' => 'Ou n&eacute;na pli lapermisyon pou g&egrave;t dann bann forom-la.',
'forum_attention_dix_caracteres' => '<b>Tansyon pangar&nbsp;!</b> out mod&eacute;kri n&eacute;na mwin 10 karakt&egrave;r-linprimri. L&eacute; pa as&eacute; pou anrozistr ali.',
'forum_attention_trois_caracteres' => '<b>Tansyon pangar&nbsp;!</b> Lo non ou la don&eacute; nana mwin 3 karact&egrave;r-linprimri.Sa l&eacute; pa as&eacute; pou anrozistr ali.',
'forum_attention_trop_caracteres' => '<b>TANSYON@circ@!</b> out\' m&egrave;zaz l&eacute; tro long\' (@compte@ karakt&egrave;r-linprimri)@circ@: pour giny anrozistr&eacute;, li doi pa f&eacute; pli d&eacute; @max@ karakt&egrave;r-linprimri',
'forum_avez_selectionne' => 'Ou la swazi&nbsp;:',
'forum_cliquer_retour' => 'Klik <a href=\'@retour_forum@\'>t&egrave;rla</a> pour as&eacute;v&eacute;.',
'forum_forum' => 'forom kozman',
'forum_info_modere' => 'Forom kozman l&eacute; mod&eacute;r&eacute;-dovan&nbsp;: l&eacute; n&eacute;s&eacute;ser inn komander la finn konfirm ali pour out kontribusyon i apar&eacute; an liyn.

',
'forum_lien_hyper' => '<b>Gatiraz</b> (l&eacute; pa obligatwar)',
'forum_message_definitif' => 'Mod&eacute;kri-la l&eacute; fini : anvwa ali si lo sitw&egrave;b',
'forum_message_trop_long' => 'Out mod&eacute;kri l&eacute; tro lon. Li dwa pa d&eacute;pas plid 20000 karakt&egrave;r-linprimri.',
'forum_ne_repondez_pas' => 'Pou r&eacute;ponn lim&eacute;l-la, anserv lo forom kozman ou sava trouv t&egrave;rla (r&eacute;ponn pa &egrave;k inn ot lim&egrave;l m&eacute; zizt inn mod&eacute;kri sir lo sitw&egrave;b):',
'forum_non_inscrit' => 'Ou l&eacute; pa inskri, kiswa out ladr&egrave;s, kiswa out modpas nana kanard&eacute;.',
'forum_page_url' => '(Si out mod&eacute;kri li ranvwa si inn lartik si lo W&egrave;b o inn ot paz pli konpl&eacute; d&eacute;or, m&egrave;rsi m&egrave;t anba lo non lapazw&egrave;b &egrave;k son ladr&egrave;s URL.)',
'forum_par_auteur' => 'sanm @auteur@',
'forum_poste_par' => 'Mod&eacute;kri-la, @parauteur@ la post ali pou r&eacute;ponn out lartik.', # MODIF
'forum_probleme_database' => 'Ast&egrave;r n&eacute;na inn larlik &egrave;k out bazdodn&eacute;. Por&eacute;zon sa minm, out mod&eacute;kri la pwinn finn d&egrave;t anrozistr&eacute;.',
'forum_qui_etes_vous' => '<b>Kisa ou l&eacute; ?</b> (r&eacute;ponn l&eacute; pa obligatwar)',
'forum_texte' => 'Lo t&egrave;ks out mod&eacute;kri :',
'forum_titre' => 'Non :',
'forum_titre_erreur' => 'Kanard...',
'forum_url' => 'URL :',
'forum_valider' => 'Konfirm out swa',
'forum_voir_avant' => 'Artourn g&eacute;t mod&eacute;kri-la avann konfirm ali',
'forum_votre_email' => 'Out ladr&egrave;s im&egrave;l  :',
'forum_votre_nom' => 'Out vr&eacute;non (ou ti-non-gat&eacute;) :',
'forum_vous_enregistrer' => 'Pou m&egrave;t ansanm dann forom-la, ifo anrozistr aou. Mersi pou m&egrave;t anba lat&egrave;r nondkod-lidantit&eacute; sak ni la donn aou. Si ou l&eacute; pa anrozistr&eacute;, i dwa',
'forum_vous_inscrire' => 'inskri a ou </a>.',

// I
'ical_texte_rss_articles' => 'Lo fisy&eacute; &laquo;backend&raquo; pou bann zartik lo sit-la, zot i va trouv ali si ladr&egrave;s-la :',
'ical_texte_rss_articles2' => 'Ou p&eacute; osi giny bann fisy&eacute; &laquo;backend&raquo; pou tout bann zartik andan ban ribrik si lo sit-la:',
'ical_texte_rss_breves' => 'N&eacute;na in ot fisy&eacute; pou bann tite-nouv&egrave;l i sort andan lo sit. Si ou pr&eacute;siz lo nim&eacute;ro laribrik-la, i sava giny s&egrave;lman bann tite-nouv&egrave;l n&eacute;na anda lo ribrik-la.',
'icone_a_suivre' => 'Pou swiv',
'icone_admin_site' => 'Kolonaz lo sitw&egrave;b',
'icone_agenda' => 'Lajinda',
'icone_aide_ligne' => 'Koudmin-w&egrave;b',
'icone_articles' => 'Bann zartik',
'icone_auteurs' => 'Bann lot&egrave;r',
'icone_breves' => 'Bann tit-nouv&egrave;l',
'icone_brouteur' => 'Bat-kar&eacute; d&eacute;gaz&eacute;',
'icone_configuration_site' => 'Konfigir lo sit',
'icone_configurer_site' => 'Konfigir out sitw&egrave;b',
'icone_creer_nouvel_auteur' => 'Kr&eacute; in nouvo lot&egrave;r ',
'icone_creer_rubrique' => 'Kr&eacute; inn rubrik',
'icone_creer_sous_rubrique' => 'Kr&eacute; inn sourubrik ',
'icone_deconnecter' => 'D&eacute;falk',
'icone_discussions' => 'Bann kozman',
'icone_doc_rubrique' => 'Bann dokiman dann bann rubrik',
'icone_ecrire_article' => '&Eacute;kri inn nouvo lartik',
'icone_edition_site' => 'L&eacute;disyon lo sitw&egrave;b',
'icone_forum_administrateur' => 'Forom kozman bann komand&egrave;r',
'icone_forum_suivi' => 'Swivi bann forom',
'icone_gestion_langues' => 'Po z&eacute;r&eacute; bann lang',
'icone_informations_personnelles' => 'Ladi Laf&eacute;',
'icone_interface_complet' => 'Lint&egrave;rfas konpl&eacute;',
'icone_interface_simple' => 'Lint&egrave;rfas sinp',
'icone_maintenance_site' => 'Lantrotyen lo sitw&egrave;b',
'icone_messagerie_personnelle' => 'Out kazmod&eacute;kri',
'icone_mots_cles' => 'Bann molakl&eacute;',
'icone_nouvelle_breve' => '&Eacute;kri inn ot tit-nouv&egrave;l',
'icone_repartition_actuelle' => 'Armontr kouk sa l&eacute; partaz&eacute; ast&egrave;r ',
'icone_repartition_debut' => 'Armontr kouk sa l&eacute; partaz&eacute; dopi lorizin',
'icone_repartition_visites' => 'Koman i partaz bann vizit',
'icone_rubriques' => 'Bann rubrik',
'icone_sauver_site' => 'Sovgard lo sitw&egrave;b',
'icone_site_entier' => 'Tout sitw&egrave;b sa minm',
'icone_sites_references' => 'Innd&eacute; sitw&egrave;b r&eacute;f&eacute;rans&eacute;',
'icone_statistiques' => 'Bann sifkl&eacute; lo sitw&egrave;b',
'icone_statistiques_visites' => 'Bann sifkl&eacute; bann vizit',
'icone_suivi_activite' => 'Po swiv lo vi lo sit',
'icone_suivi_actualite' => 'L&eacute;volisyon&nbsp;lo sit',
'icone_suivi_forums' => 'Swiv/aranz bann forom',
'icone_suivi_pettions' => 'Swiv/aranz filsinyatir',
'icone_suivi_revisions' => 'Bann sanzman do bann zartik',
'icone_supprimer_document' => 'D&eacute;gr&egrave;n dokiman-la',
'icone_supprimer_image' => 'D&eacute;gr&egrave;n limaz-la',
'icone_supprimer_message' => 'D&eacute;gr&egrave;n mod&eacute;kri-la',
'icone_tous_articles' => 'Tout bann zartik aou',
'icone_tous_auteur' => 'Tout bann lot&egrave;r',
'icone_valider_message' => 'Konfirm mod&eacute;kri-la',
'icone_visiter_site' => 'Bat-kar&eacute; ',
'icone_voir_en_ligne' => 'Vwar an liyn',
'image_tourner_180' => 'Toun&eacute; 180&deg;',
'image_tourner_droite' => 'toun&eacute; drwat 90&deg; ',
'image_tourner_gauche' => 'Toun&eacute; goch 90&deg; ',
'img_indisponible' => 'zimaj-la l&eacute; pa posib giny ali',
'impossible' => 'pa posib',
'info_a_suivre' => 'POU SWIV&nbsp;&raquo;',
'info_a_valider' => '[pou konfirmasyon]',
'info_acces_interdit' => 'Ou n&eacute;na pwinn permisyon akost lapazw&egrave;b-la.',
'info_acces_refuse' => 'Lakostaz lapazw&egrave;b l&eacute; afront&eacute;',
'info_action' => 'Azisman : @action@',
'info_administrer_rubriques' => 'Ou p&eacute; z&egrave;r larubrik-la &egrave;k son bann sourubrik',
'info_adresse_non_indiquee' => 'Ou n&eacute;na pwin mi ladr&egrave;s sak i v&eacute; test ast&egrave;r&nbsp;!',
'info_aide' => 'KOUDMIN :',
'info_ajouter_mot' => 'Azout lo mo',
'info_annonce' => 'ZANONS',
'info_annonces_generales' => 'Zanons a tout moun&nbsp;:',
'info_article_propose' => 'Lartik l&eacute; propoz&eacute;',
'info_article_publie' => 'Lartik l&eacute; publiy&eacute;',
'info_article_redaction' => 'Lartik antrin l&eacute;kritir ',
'info_article_refuse' => 'Lartik l&eacute; afront&eacute;',
'info_article_supprime' => 'Lartik l&eacute; d&eacute;gr&eacute;n&eacute;',
'info_articles' => 'Bann zartik',
'info_articles_a_valider' => 'Bann zartik pou konfirm&eacute;',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => 'Bann zartik sak l&eacute; propoz&eacute;',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => '(bann) lot&egrave;r&nbsp;:',
'info_authentification_ftp' => 'Lotantificasyon (&egrave;k FTP).',
'info_bloquer_lien' => 'blok lo gatiraz-la',
'info_breves_02' => 'Bann tit-nouv&egrave;l',
'info_breves_2' => 'bann tit-nouv&egrave;l',
'info_breves_nb' => '@nb@ br&egrave;ves', # NEW
'info_breves_un' => '1 br&egrave;ve', # NEW
'info_breves_valider' => 'Bann tit-nouv&egrave;l pou konfirm&eacute;',
'info_connexion_refusee' => 'Lakostaz l&eacute; arfiz&eacute;',
'info_contact_developpeur' => 'Mersi kontak inn d&eacute;vlop&egrave;r.',
'info_contenance' => 'Dann sit-la nana&nbsp;:',
'info_contribution' => 'bann kontribusyon dann forom',
'info_copyright' => '@spip@ l&eacute; inn lozisyel lib sak l&eacute; don&eacute; @lien_gpl@.',
'info_copyright_doc' => 'Pou plid zinformasyon anon vizit lo sit <a href="@spipnet@">http://www.spip.net/cpf</a>.', # MODIF
'info_copyright_gpl' => 'sou lisans GPL',
'info_cours_edition' => 'Out bann zartik l&eacute; apr&eacute; l&eacute;disyon',
'info_creer_repertoire' => 'Mersi kr&eacute; inn fisy&eacute; o inn r&eacute;pertwar &egrave;k non-la&nbsp;:',
'info_creer_repertoire_2' => 'andann lo sou-r&eacute;pertwar <b>@repertoire@</b>, &eacute; apr&egrave;&nbsp;:',
'info_creer_vignette' => 'pou kr&eacute;y inn tite-limaz otomatikman',
'info_deplier' => 'D&eacute;pliy',
'info_descriptif_nombre' => 'Bann zaf&egrave;r sak i kontyin&nbsp;:',
'info_description' => 'Kosa ou va trouv isi&nbsp;:',
'info_description_2' => 'Kosa ou va trouv isi&nbsp;:',
'info_dimension' => 'Dimansyon&nbsp;:',
'info_document' => 'Dokiman',
'info_document_indisponible' => 'Ce document n\'est pas disponible', # NEW
'info_documents' => 'Bann dokiman',
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => '&Egrave;k SPIP ou p&eacute; anvway&eacute; bann mod&eacute;kri &eacute; f&eacute; zw&eacute; bann forom kozman
(forom priv&eacute;) antrozot. L&eacute; posib m&egrave;t ou d&eacute;gr&egrave;n fonksyon-la kom sak ou v&eacute;.',
'info_ecire_message_prive' => 'Pou kr&eacute; inn mod&eacute;kri priv&eacute;',
'info_email_invalide' => 'Out ladr&egrave;s im&egrave;l l&eacute; pa bon.',
'info_en_cours_validation' => 'Out bann zartik-la l&eacute; apr&eacute; l&eacute;kritir',
'info_en_ligne' => 'An liyn ast&egrave;r&nbsp;:',
'info_envoyer_message_prive' => 'Anvwa inn mod&eacute;kri priv&eacute; pou lot&egrave;r-la',
'info_erreur_requete' => 'Kanard dann rok&egrave;t-la :',
'info_erreur_squelette2' => 'N&eacute;na pa okin l&eacute;sk&eacute;l&egrave;t <b>@fichier@</b> sat l&eacute; disponib...',
'info_erreur_systeme' => 'Kanar sist&egrave;m (errno @errsys@)',
'info_erreur_systeme2' => 'Lo diksodir li sr&eacute; byin po &egrave;t kompl&egrave;tman ragoul&eacute; o labazdodn&eacute; l&eacute; gat&eacute;<br />
 <font color=\'red\'>Anon esay&eacute; <a href=\'@script@\'>aranz&eacute; labaz</a>,
 ou kontakt&eacute; out l&eacute;b&egrave;rz&egrave;r.</font>', # MODIF
'info_fini' => 'Ast&egrave;r sa l&egrave; fini !',
'info_format_image' => 'Bann tay-zimaz ou p&eacute; itiliz&eacute; pou kr&eacute; out bann viny&egrave;t&nbsp;: @gd_formats@.',
'info_format_non_defini' => 'forma-la l&eacute; pa kadr&eacute;',
'info_grand_ecran' => 'Gran l&eacute;kran',
'info_image_aide' => 'KOUDMIN',
'info_image_process_titre' => 'Koman ou p&eacute; kr&eacute; bann tit-zimaz',
'info_impossible_lire_page' => '<b>Kanard !</b> L&eacute; inposib lir pazw&egrave;b-la <tt><html>@test_proxy@</html></tt> &egrave;k lo proksi <tt>', # MODIF
'info_inclusion_directe' => 'Linklizyon dir&egrave;k&nbsp;:',
'info_inclusion_vignette' => 'Linklizyon limaz-minyatir&nbsp;:',
'info_installation_systeme_publication' => 'Pou f&eacute; zw&eacute; (instal) lo sist&egrave;m lapiblikasyon...',
'info_installer_documents' => 'Ou p&eacute; f&egrave; zw&eacute; otomatikman tout bann dokiman sak l&eacute; pr&eacute;zan dann fisy&eacute; @upload@.',
'info_installer_ftp' => 'Kom komand&egrave;r, ou p&eacute; instal (&egrave;k FTP) bann fisy&eacute; dann dosy&eacute; @upload@ pou answuit swazi banna t&egrave;rla dir&egrave;kman.',
'info_installer_images' => 'Ou p&eacute; f&egrave;r zw&eacute; bann zimaz &egrave;k lo forma JPEG, GIF &eacute; minm PNG.',
'info_installer_images_dossier' => 'Instal bann zimaz dann dosy&eacute; @upload@ pou swazi azot answit, t&egrave;rla dir&egrave;kman.',
'info_installer_tous_documents' => 'Instal tout bann dokiman-minm',
'info_interface_complete' => 'Lint&egrave;rfas konpl&eacute;',
'info_interface_simple' => 'Lint&egrave;rfas sinp',
'info_joindre_document_article' => 'Dann zartik-la, ou p&eacute; zwinn innd&eacute; dokiman kom',
'info_joindre_document_rubrique' => 'Dann rubrik-la ou p&eacute; azout innd&eacute; dokiman kom',
'info_joindre_documents_article' => 'Dann out zartik ou p&eacute; zwinn innd&eacute; dokiman kom&nbsp;:',
'info_l_article' => 'lartik',
'info_la_breve' => 'la tit-nouv&egrave;l',
'info_la_rubrique' => 'rubrik',
'info_langue_principale' => 'Lang prinsipal lo sitw&egrave;b',
'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ bann piks&egrave;l',
'info_les_auteurs_1' => '&egrave;k @les_auteurs@',
'info_logo_format_interdit' => 'L&eacute; posib m&egrave;t s&egrave;lman bann logo dann bann forma @formats@.',
'info_logo_max_poids' => 'Fok out bann logo nena in pwa andsou @maxi@ (fichy&eacute; la li f&eacute; @actuel@).',
'info_logo_max_taille' => 'Fok out bann logo nena inn tay andsou  @maxi@ (fichye la li f&eacute; @actuel@).',
'info_mail_fournisseur' => 'out@fournis&egrave;r.com',
'info_message_2' => 'MODEKRI',
'info_message_supprime' => 'MOD&Eacute;KRI SUPRIM&Eacute;',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => 'Dat pou m&egrave;t an liyn&nbsp;:',
'info_modification_parametres_securite' => 'bann sanzman bann param&egrave;t las&eacute;kirit&eacute;',
'info_mois_courant' => 'Dann kouran lo mwa :',
'info_mot_cle_ajoute' => 'Molakl&eacute;-la la finn d&egrave;t azout&eacute; dann',
'info_multi_herit' => 'Lang laribrik anl&egrave;r',
'info_multi_langues_soulignees' => 'Bann <u>lang souliny&eacute; </u> l&eacute; sat n&eacute;na in traidksyonkompl&eacute; po tout bann t&egrave;ks lint&eacute;rfas SPIP. Si ou swazi bann lang-la, n&eacute;na in bon p&eacute;d z&eacute;l&eacute;man lo sit piblik (ladat, bann formil&egrave;r) sak i apar&eacute; tradwi otomatikman. Ek tout bann lang sat l&eacute; pa souliny&eacute;, bann z&eacute;l&eacute;amn-la i apar&eacute; samn lo lang prinsipal lo sit.', # MODIF
'info_multilinguisme' => 'Miltilingwis',
'info_nom_non_utilisateurs_connectes' => 'Out non l&eacute; pa visib dann fil bann zitilizat&egrave;r an liyn.',
'info_nom_utilisateurs_connectes' => 'Out non l&eacute; vizib dann list bann zitilizat&egrave;r an liyn.',
'info_nombre_en_ligne' => 'Ast&egrave;r l&eacute; an liyn&nbsp;:',
'info_non_resultat' => 'Nana pwinn r&eacute;zilta pou "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'Ast&egrave;r i ans&egrave;rv pa lakazmod&eacute;kri lo sitw&egrave;b.',
'info_nouveau_message' => 'OU NA INN NOUVO MOD&Eacute;KRI',
'info_nouveaux_messages' => 'OU N&Egrave;NA @total_messages@ BANN MOD&Eacute;KRI',
'info_numero_abbreviation' => 'N&deg;&nbsp;',
'info_obligatoire' => 'Cette information est obligatoire', # NEW
'info_panne_site_syndique' => 'Lo sit sindik&eacute;-la l&eacute; an pan',
'info_pense_bete' => 'GARDANT&Egrave;T',
'info_petit_ecran' => 'Tit &eacute;kran',
'info_petition_close' => 'P&eacute;tition close', # NEW
'info_pixels' => 'bann piks&egrave;l',
'info_plusieurs_mots_trouves' => 'Nana plizi&egrave;r bann molakl&eacute; pou "@cherche_mot@":',
'info_popularite_5' => 'popularit&eacute;&nbsp;:',
'info_portfolio' => 'Portfolio',
'info_portfolio_automatique' => 'Livzimaz otomatik&nbsp;:',
'info_premier_resultat' => '[@debut_limit@ bann promy&eacute; r&eacute;zilta si @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ bann promy&eacute; r&eacute;zilta si @total@]',
'info_probleme_grave' => 'kanard &egrave;k',
'info_propose_1' => '[@nom_site_spip@] i propoz aou : @titre@',
'info_propose_2' => 'Lartik-la l&eacute; propoz&eacute;
---------------',
'info_propose_3' => 'Lartik-la, "@titre@", l&eacute; propoz&eacute; pou lapiblikasyon.',
'info_propose_4' => 'Anon zot lir ali &egrave; donn zot many&egrave;r dvwar',
'info_propose_5' => 'dann forom sak i bord ali. Ou va trouv ali si ladr&egrave;s-la :',
'info_publie_01' => 'Lartik "@titre@" la finn d&egrave;t konfirm&eacute; sanm @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] I PUBLIY : @titre@',
'info_publie_2' => 'Lartik-la l&eacute; pibliy&eacute;
---------',
'info_rechercher' => 'Rod',
'info_rechercher_02' => 'Rod&nbsp;:',
'info_remplacer_vignette' => 'Sanz laviny&egrave;t sanswa kont out prop logo&nbsp;:',
'info_retablir_lien' => 'Arm&egrave;t lo gatir d&eacute;gr&eacute;n&eacute;-la',
'info_retirer_mot' => 'Anl&egrave;v mo-la',
'info_retirer_mots' => 'Anl&egrave;v tout bann mo',
'info_rubriques_nb' => '@nb@ rubriques', # NEW
'info_rubriques_un' => '1 rubrique', # NEW
'info_sans_titre_2' => 'n&eacute;na pwinn titr',
'info_selectionner_fichier' => 'Ou i p&eacute; swazi in fisy&eacute; dann dosy&eacute; @upload@',
'info_selectionner_fichier_2' => 'Swazi inn fisy&eacute;&nbsp;:',
'info_signature_supprimee' => 'Signature supprim&eacute;e', # NEW
'info_signature_supprimee_erreur' => 'Erreur&nbsp;: ce code de suppression ne correspond a aucune signature', # NEW
'info_site_attente' => 'Sitw&egrave;b-la l&eacute; apr&eacute; esp&egrave;r lakonfirmasyon',
'info_site_reference' => 'Sitw&egrave;b r&eacute;f&eacute;rans&eacute; an liyn',
'info_site_refuse' => 'Sitw&egrave;b-la l&eacute; arfiz&eacute;',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => 'R&eacute;f&eacute;rans inn sitw&egrave;b',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => 'd&eacute;gr&egrave;n viny&egrave;t-la',
'info_symbole_bleu' => 'Lo sinbol <b>bl&eacute;</b> li mark <b>inn gardant&egrave;t</b>: inn mod&eacute;kri pour out prop lisaz.', # MODIF
'info_symbole_jaune' => 'Lo sinbol <b>zon</b> li mark <b>inn zanons pou tout bann lot&egrave;r</b>&nbsp;: banna i p&eacute; vwar ali an liyn ; bann komand&egrave;r i p&eacute; sanz ali.', # MODIF
'info_symbole_vert' => 'Lo sinbol <b>v&egrave;r</b> i mark <b>bann mod&eacute;kri &egrave;k dot bann zitilizat&egrave;r</b> lo sitw&egrave;b.', # MODIF
'info_syndication' => 'Lasindikasyon :',
'info_syndication_articles' => '(bann) lartik',
'info_telecharger' => 'T&eacute;l&eacute;sarz dopwi out prop lordinat&egrave;r&nbsp;:',
'info_telecharger_nouveau_logo' => 'T&eacute;l&eacute;sarz inn nouvo logo&nbsp;:',
'info_telecharger_ordinateur' => 'T&eacute;l&eacute;sarz dopwi out prop lordinat&egrave;r&nbsp;:',
'info_tous_resultats_enregistres' => '[tout bann r&eacute;zilta la finn d&egrave;t anroziztr&eacute;]',
'info_tout_afficher' => 'Afis tout',
'info_travaux_texte' => 'Si lo sit-la l&eacute; pa konfigir&eacute;, arvyin inn p&eacute; pli tar...',
'info_travaux_titre' => 'Sit-la l&eacute; apr&eacute; travay b&egrave;rlok  ou p&egrave;t&egrave;t travay santy&eacute;...l&eacute; pa finn ankor ast&egrave;r... ',
'info_trop_resultat' => 'Nana tro bann r&eacute;zilta pou "@cherche_mot@" ; mersi kadr my&eacute; lo rodaz.',
'info_utilisation_messagerie_interne' => 'Ou ans&egrave;rv lakazmod&eacute;kri lo sitw&egrave;b.',
'info_valider_lien' => 'konfirm gatir-la',
'info_verifier_image' => ', mersi g&egrave;t ankor out bann zimaz la finn d&egrave;t sarz&eacute; kor&egrave;kman sir lo serv&egrave;r.',
'info_vignette_defaut' => 'Viny&egrave;t sanswa',
'info_vignette_personnalisee' => 'Out prop viny&egrave;t',
'info_visite' => 'vizit :',
'info_visites' => 'bann vizit :',
'info_vos_rendez_vous' => 'Out bann prosin rand&eacute;vou',
'info_zoom' => 'zoum',
'infos_vos_pense_bete' => 'Out bann gardant&egrave;t', # MODIF
'item_breve_proposee' => 'Tit-nouv&egrave;l-la l&eacute; propoz&eacute;',

// L
'lien_afficher_icones_seuls' => 'Afis s&egrave;lman bann zikon',
'lien_afficher_texte_icones' => 'Afis bann zikon &egrave;k lo t&egrave;ks',
'lien_afficher_texte_seul' => 'Afis s&egrave;lman lo t&egrave;ks',
'lien_liberer' => 'Maronn',
'lien_liberer_tous' => 'maronn tout bann zartik-la',
'lien_nouvea_pense_bete' => 'NOUVO GARDANT&Egrave;T',
'lien_nouveau_message' => 'NOUVO MOD&Eacute;KRI',
'lien_nouvelle_annonce' => 'NOUVEL ZANONS',
'lien_petitions' => 'FILSINYATIR',
'lien_popularite' => 'Koman l&eacute; popul&egrave;r&nbsp;: @popularite@%',
'lien_racine_site' => 'RASIN LO SITW&Egrave;B',
'lien_reessayer' => '&eacute;s&egrave;y ankor',
'lien_repondre_message' => 'R&eacute;ponn mod&eacute;kri-la',
'lien_supprimer' => 'd&eacute;gr&egrave;n',
'lien_tout_afficher' => 'Afis tout',
'lien_visite_site' => 'vizit lo sit-la',
'lien_visites' => '@visites@&nbsp;bann vizit',
'lien_voir_auteur' => 'G&egrave;t lot&egrave;r-la',
'ligne' => 'Ligne', # NEW
'login' => 'Connexion', # NEW
'login_acces_prive' => 'laks&eacute; pou l&eacute;spas priv&eacute;',
'login_autre_identifiant' => 'Akost lo sit &egrave;k inn nouv&egrave;l nondkod',
'login_cookie_accepte' => 'Mersi r&egrave;gl a zot navigat&egrave;r pou li as&egrave;pt azot (mwindreman pou sitw&egrave;b-la).',
'login_cookie_oblige' => 'Pou inn lidantifikasyon sir si lo sit, ou dwa as&eacute;pt&eacute; bann gatomakro.',
'login_deconnexion_ok' => 'Out d&eacute;falkaz la finn mars&eacute;.',
'login_erreur_pass' => 'Kanard &egrave;k lo modpas.',
'login_espace_prive' => 'L&eacute;spas priv&eacute;',
'login_identifiant_inconnu' => 'Lo nondkod &laquo; @login@ &raquo; li l&eacute; pa konu.',
'login_login' => 'Nondkod :',
'login_login2' => 'Nondkod (lidantifian pou lakostaz lo sitw&egrave;b)&nbsp;:',
'login_login_pass_incorrect' => '(Out nondkod ou modpas l&eacute; pa kor&egrave;k.)',
'login_motpasseoublie' => 'Ou&nbsp;la&nbsp;oubliy&eacute;&nbsp;out&nbsp;modpas&nbsp;?',
'login_non_securise' => 'Tansyon pangar, formul&egrave;r-la l&eacute; pa s&eacute;kiriz&eacute;.
Si ou v&eacute; pa person i atrap out modpass si lo r&eacute;zo
mersi f&eacute; zw&eacute; lo Javascript 
dann out navigat&egrave;r &eacute;',
'login_nouvelle_tentative' => 'Nouv&egrave;l &eacute;s&eacute;',
'login_par_ici' => 'Ou l&eacute; anroziztr&eacute;... dann kwin-la...',
'login_pass2' => 'Modpas&nbsp;:',
'login_preferez_refuser' => '<b>Si ou pr&eacute;f&egrave;r afront bann gatomakro</b>,nana inn ot sist&egrave;m lakostaz (mwin sir)&nbsp;sak ou p&eacute; anserv:',
'login_recharger' => 'rosarz pazw&egrave;b-la',
'login_rester_identifie' => 'Po inn lidantifikasyon i dir plisy&egrave;r zor',
'login_retour_public' => 'Artourn sir figirw&egrave;b',
'login_retour_site' => 'Artourn sir figirw&egrave;b',
'login_retoursitepublic' => 'artourn&nbsp;sir&nbsp;figirw&egrave;b',
'login_sans_cookiie' => 'Lidantifikasyon san lo gatomakro',
'login_securise' => 'Login s&eacute;curis&eacute;', # NEW
'login_sinscrire' => 'inskri aou',
'login_test_navigateur' => 'test navigat&egrave;r/nouvo lakostaz',
'login_verifiez_navigateur' => '(Somansa g&eacute;t byin out navigat&egrave;r la pa gardant&egrave;t out modpass...)',

// M
'masquer_colonne' => 'Masquer cette colonne', # NEW
'masquer_trad' => 'masquer les traductions', # NEW
'module_fichiers_langues' => 'Bann fisy&eacute; lang',

// N
'navigateur_pas_redirige' => 'Si out navigat&egrave;r l&eacute; pa rotourn&eacute;, apiy t&egrave;rla pou kontiny&eacute;.',
'numero' => 'Num&eacute;ro', # NEW

// O
'occurence' => 'Occurrence', # NEW
'onglet_affacer_base' => 'D&eacute;gr&egrave;n labazdodn&eacute;',
'onglet_auteur' => 'Lot&egrave;r',
'onglet_contenu_site' => 'Sak lo sit i kontyin',
'onglet_evolution_visite_mod' => 'Sanzman',
'onglet_fonctions_avances' => 'Bann fonksyon pr&eacute;siz',
'onglet_informations_personnelles' => 'Bann zinformasyon lot&egrave;r',
'onglet_interactivite' => 'Kozantrozot',
'onglet_messagerie' => 'Kazmod&eacute;kri',
'onglet_messages_internes' => 'Bann mod&eacute;kri-dodan',
'onglet_messages_publics' => 'Bann mod&eacute;kri-d&eacute;or',
'onglet_messages_vide' => 'Bann mod&eacute;kri san t&egrave;ks',
'onglet_origine_visites' => 'Lorizin bann vizit',
'onglet_repartition_debut' => 'dopwi komansman',
'onglet_repartition_lang' => 'Bann vizit sanm tout bann lang',
'onglet_repartition_rubrique' => 'Partaz sanm rubrik',
'onglet_save_restaur_base' => 'Sovgard/rosarz l&eacute;ta labaz',
'onglet_vider_cache' => 'D&eacute;vid lo kas',

// P
'pass_choix_pass' => 'Mersi swazi out nouvo modpas :',
'pass_erreur' => 'Kanard',
'pass_erreur_acces_refuse' => '<b>Kanard :</b> out nana pli laks&eacute; sir lo sit-la.',
'pass_erreur_code_inconnu' => '<b>Kanard :</b> lo kod-la i korespon pa pou okin lot&egrave;r anroziztr&eacute; si lo sit.',
'pass_erreur_non_enregistre' => '<b>Kanard :</b> ladr&egrave;s-la <tt>@email_oubli@</tt> li l&eacute; pli anroziztr&eacute; si lo sit-la.',
'pass_erreur_non_valide' => '<b>Kanard : /b> lim&egrave;l-la <tt>@email_oubli@</tt> l&eacute; pa bon !',
'pass_erreur_probleme_technique' => '<b>Kanard  :</b> akoz inn larlik t&egrave;knik, l&eacute; pa posib ast&egrave;r anvway&eacute; lim&egrave;l-la.',
'pass_espace_prive_bla' => 'L&eacute;spas priv&eacute; lo sit-la l&eacute; ouv&egrave;r pou tout
bann vizit&egrave;r, apr&egrave; linskrisyon. Kank ou l&eacute; anroziztr&eacute;,
i p&eacute; konsilt oubyinsa propoz bann zartik.I p&eacute; osi
m&egrave;t ansanm &egrave;k bann dalon dan tout bann forom.',
'pass_forum_bla' => 'Ou la domand m&egrave;t out grinds&egrave;l dann forom
sak l&eacute; r&eacute;z&egrave;rv&eacute; pou bann vizit&egrave;r anrozistr&eacute;.',
'pass_indiquez_cidessous' => 'M&egrave;t isi ladr&egrave;s im&egrave;l ou la d&eacute;za anservi pou anroziztr aou. Apr&eacute;sa, ou sava
giny inn lim&egrave;l : li indik aou lamanyir pou r&eacute;kup&egrave;r out laks&eacute;.',
'pass_mail_passcookie' => '(Sa l&eacute; in mod&eacute;kri otomatik)
Pour ou i p&eacute; artrouv out laks&eacute; si lo sitw&egrave;b
@nom_site_spip@ (@adresse_site@)

Mersi rand aou sir ladr&egrave;s la :
    @sendcookie@

Apr&eacute;sa, ou i poura m&egrave;t in nouvo modpas
 pou rakost lo sitw&egrave;b.
',
'pass_mot_oublie' => 'Modpas oubliy&eacute;',
'pass_nouveau_enregistre' => 'Out nouvo modpas la fin d&egrave;t anroziztr&eacute;.',
'pass_nouveau_pass' => 'Nouvo modpas',
'pass_ok' => 'Dakor',
'pass_oubli_mot' => 'Modpas oubly&eacute;',
'pass_quitter_fenetre' => 'D&eacute;falk fin&egrave;t-la',
'pass_rappel_login' => 'Rap&egrave;l aou : out lidantifyan (nondkod) l&eacute; &laquo; @login@ &raquo;.',
'pass_recevoir_mail' => 'Ou sava giny inn lim&egrave;l sak i indik aou kouk sa i p&eacute; artrouv out laks&eacute; sir lo sit.',
'pass_retour_public' => 'Artourn sir figirw&egrave;b',
'pass_rien_a_faire_ici' => 'Nana ryinn a f&egrave;r isi.',
'pass_vousinscrire' => 'Inskri aou sir lo sit',
'precedent' => 'dovan',
'previsualisation' => 'Po vwar avann komsi l&eacute; an liny',
'previsualiser' => 'Po vwar avan',

// R
'retour' => 'Retour', # NEW

// S
'spip_conforme_dtd' => 'SPIP consid&egrave;re ce document comme conforme &agrave; son DOCTYPE :', # NEW
'squelette' => 'l&eacute;skel&egrave;t',
'squelette_inclus_ligne' => 'lesk&eacute;l&egrave;t dodan, liny',
'squelette_ligne' => 'l&eacute;skel&egrave;t, liny',
'stats_visites_et_popularite' => '@visites@ vizit&nbsp;; popularit&eacute;&nbsp;: @popularite@',
'suivant' => 'd&egrave;ry&egrave;r',

// T
'taille_ko' => '@taille@&nbsp;ko',
'taille_mo' => '@taille@&nbsp;Mo',
'taille_octets' => '@taille@&nbsp; bann zokt&eacute;',
'texte_actualite_site_1' => 'Kank ou sra pli zabity&eacute; &egrave;k lo figirw&egrave;b, i poura klik sir &laquo;',
'texte_actualite_site_2' => 'lint&egrave;rfas konpl&eacute;',
'texte_actualite_site_3' => '&raquo; pour giny plid posibilit&eacute;.',
'texte_creation_automatique_vignette' => 'Lakr&eacute;asyon otomatik pou bann viny&egrave;t avwar-avan, l&eacute; an mars si lo sit-la. Si ou linstal bann zimaz dann (bann) tay  @gd_formats@, dopwi formul&egrave;r-la, zimaz-la i sra pr&eacute;zant&eacute; &egrave;k inn viny&egrave;t pa pli grank @taille_preview@&nbsp; bann piks&egrave;l oplis.',
'texte_documents_associes' => 'Bann dokiman-la l&eacute; mi &egrave;k lartik-la,
m&eacute; zot l&eacute; pa plas&eacute; dann kor-minm lartik-la. S&eacute;lon lamanyir ou sava m&egrave;t an paz lo sit piblik,
zot i sra pou apar&egrave;t kom bann dokiman zwinn.',
'texte_erreur_mise_niveau_base' => 'Kanard do bazdodn&eacute; dann tan larmizanivo .
Limaz <b>@fichier@</b> la pa pas&eacute; dann (article @id_article@).
Gard byin an t&egrave;t r&eacute;f&eacute;rans-la, &eacute;s&egrave;y inn ot fwa inn larmizanivo, &eacute; v&eacute;y byin sak bann zimaz i apar&eacute; touzour dann bann zartik.', # MODIF
'texte_erreur_visiteur' => 'Vous avez tent&eacute; d\'acc&eacute;der &agrave; l\'espace priv&eacute; avec un login qui ne le permet pas.', # NEW
'texte_inc_auth_1' => 'Ou l&eacute; konu sir lo sit &egrave;k lo
 nondkod <b>@auth_login@</b>, m&eacute; li l&eacute; pa/pli pr&eacute;zan ast&egrave;r dann labaz. 
Es&egrave;y', # MODIF
'texte_inc_auth_2' => 'rakost inn ot fwa',
'texte_inc_auth_3' => 'apr&eacute; ou la pet&egrave;t sort &egrave;k ard&eacute;mar out
navigat&egrave;r.',
'texte_inc_config' => 'Bann sanzman sir bann paz-la na inn l&eacute;f&eacute; importan sir lamanyir
out sit i mars. Ni kons&egrave;y aou pa tous a ryin si ou l&eacute; pa fransv&eacute;rit&eacute; byin abity&eacute; &egrave;k lo sist&egrave;m SPIP.

 <br /><br /><b>&Eacute; minm, ni kons&eacute;y
aou l&egrave;s laz&eacute;styon do bann paz-la pou lo w&egrave;bm&egrave;t prinsipal.</b>', # MODIF
'texte_inc_meta_1' => 'Sist&egrave;m-la la finn trov&eacute; inn larlik &egrave;k l&eacute;kritir lo fisy&eacute; <code>@fichier@</code>.  Mersi, kom komand&egrave;r lo sit,',
'texte_inc_meta_2' => 'v&eacute;rify&eacute; bann drwa l&eacute;kritir',
'texte_inc_meta_3' => 'dann r&eacute;pertwar <code>@repertoire@</code>.',
'texte_statut_en_cours_redaction' => 'apr&eacute; l&eacute;kritir',
'texte_statut_poubelle' => 'dann korb&egrave;y',
'texte_statut_propose_evaluation' => 'propoz&eacute; pou zot zizman',
'texte_statut_publie' => 'pibliy&eacute; an liyn',
'texte_statut_refuse' => 'arfiz&eacute;',
'titre_ajouter_mot_cle' => 'AZOUT INN MOLAKL&Eacute; :',
'titre_breve_proposee' => 'Tit-nouv&egrave;l propoz&eacute;',
'titre_breve_publiee' => 'Tit-nouv&egrave;l pibliy&eacute;',
'titre_breve_refusee' => 'Tit-nouv&egrave;l arfiz&eacute;',
'titre_cadre_raccourcis' => 'BANN R&Eacute;DIYON:',
'titre_changer_couleur_interface' => 'Sanz lakoul&egrave;r lint&egrave;rfas',
'titre_forum' => 'Forom ',
'titre_image_admin_article' => 'Ou p&eacute; z&egrave;r lartik-la',
'titre_image_administrateur' => 'Komand&egrave;r',
'titre_image_aide' => 'Koudmin sir l&eacute;l&eacute;man-la',
'titre_image_auteur_supprime' => 'Lot&egrave;r l&eacute; d&eacute;gr&eacute;n&eacute;',
'titre_image_redacteur' => 'Lot&egrave;r san laks&eacute;',
'titre_image_redacteur_02' => 'Lot&egrave;r',
'titre_image_visiteur' => 'Vizit&egrave;r',
'titre_joindre_document' => 'POU ZWIND INN DOKIMAN',
'titre_liens_entrants' => 'Bann gatiraz lariv&eacute;',
'titre_mots_cles' => 'BANN MOLAKL&Eacute;',
'titre_probleme_technique' => 'Pangar&nbsp;: inn larlik t&egrave;knik (serv&egrave;r SQL) i d&eacute;fann permisyon lakostaz dan landrwa la. &Eacute;skiz anou.', # MODIF
'titre_publier_document' => 'PUBLIY INN DOKIMAN DANN RUBRIK-LA',
'titre_signatures_attente' => 'Signatures en attente de validation', # NEW
'titre_signatures_confirmees' => 'Signatures confirm&eacute;es', # NEW
'titre_statistiques' => 'Sifkl&eacute; lo sitw&egrave;b',
'titre_titre_document' => 'Lo non dokiman-la&nbsp;:',
'todo' => '&agrave; venir', # NEW
'trad_reference' => '(Lartik-p&eacute;i de r&eacute;f&eacute;rans)',

// Z
'zbug_balise_b_aval' => '&nbsp;: baliz B anl&egrave;r',
'zbug_balise_inexistante' => 'erreur @from@: la balise #@balise@ n\'existe pas', # MODIF
'zbug_balise_sans_argument' => 'Argument manquant dans la balise @balise@', # NEW
'zbug_boucle' => 'boukl',
'zbug_boucle_recursive_undef' => 'boukl r&eacute;kirsiv-la l&eacute; pa d&eacute;fini', # MODIF
'zbug_calcul' => 'calcul', # NEW
'zbug_champ_hors_boucle' => 'lo chan @champ@ l&eacute; and&eacute;or in boukl',
'zbug_champ_hors_motif' => 'Lo chan @champ@ l&eacute; an d&eacute;or in boukl-motif @motif@', # MODIF
'zbug_code' => 'kod',
'zbug_critere_inconnu' => 'krit&egrave;r-la l&eacute; pa konu @critere@', # MODIF
'zbug_distant_interdit' => 'd&eacute;or interdi', # MODIF
'zbug_doublon_table_sans_cle_primaire' => 'doublons sur une table sans clef primaire atomique', # MODIF
'zbug_doublon_table_sans_index' => 'doublons sur une table sans index', # MODIF
'zbug_erreur_boucle_double' => 'BOUCLE@id@: n&eacute;na d&eacute; d&eacute;finisyon', # MODIF
'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: n&eacute;na in "tag" sat i mank po tak in boukl.', # MODIF
'zbug_erreur_boucle_syntaxe' => 'Sintask lo boukl-l&agrave; l&eacute; pa kor&egrave;k', # MODIF
'zbug_erreur_compilation' => 'Erreur de compilation', # NEW
'zbug_erreur_execution_page' => 'n&eacute;na in larlik pou l&eacute;x&eacute;kisyon paj-la', # MODIF
'zbug_erreur_filtre' => 'N&eacute;na in kanar andan lo filt <b>&laquo; @filtre@ &raquo;</b> sat l&eacute; pa d&eacute;fini', # MODIF
'zbug_erreur_meme_parent' => '{meme_parent} li aplik s&egrave;lman pou bann boukl (FORUMS) ou (RUBRIQUES)', # MODIF
'zbug_erreur_squelette' => 'n&eacute;na (bann) larlik andan l&eacute;sk&eacute;l&egrave;t',
'zbug_hors_compilation' => 'Hors Compilation', # NEW
'zbug_info_erreur_squelette' => 'Kanar sir lo sit',
'zbug_inversion_ordre_inexistant' => 'lord existan l&eacute; invers&egrave;', # MODIF
'zbug_pagination_sans_critere' => '#PAGINATION sans crit&egrave;re {pagination} ou employ&eacute; dans une boucle recursive', # MODIF
'zbug_parametres_inclus_incorrects' => 'Bann param&egrave;t pou linklizyon l&eacute; pa kor&egrave;k', # MODIF
'zbug_profile' => 'Temps de calcul&nbsp;: @time@', # NEW
'zbug_resultat' => 'r&eacute;zilta',
'zbug_serveur_indefini' => 'serv&egrave;r SQL la l&eacute; pa d&eacute;fini', # MODIF
'zbug_statistiques' => 'Statistiques des requ&ecirc;tes SQL class&eacute;es par dur&eacute;e', # NEW
'zbug_table_inconnue' => 'Lo tab SQL &laquo; @table@ &raquo;  la , li l&eacute; pa konu',
'zxml_connus_attributs' => 'attributs connus', # NEW
'zxml_de' => 'de', # NEW
'zxml_inconnu_attribut' => 'attribut inconnu', # NEW
'zxml_inconnu_balise' => 'balise inconnue', # NEW
'zxml_inconnu_entite' => 'entit&eacute; inconnue', # NEW
'zxml_inconnu_id' => 'ID inconnu', # NEW
'zxml_mais_de' => 'mais de', # NEW
'zxml_non_conforme' => 'n\'est pas conforme au motif', # NEW
'zxml_non_fils' => 'n\'est pas un fils de', # NEW
'zxml_nonvide_balise' => 'balise non vide', # NEW
'zxml_obligatoire_attribut' => 'attribut obligatoire mais absent dans', # NEW
'zxml_succession_fils_incorrecte' => 'succession des fils incorrecte', # NEW
'zxml_survoler' => 'survoler pour voir les corrects', # NEW
'zxml_valeur_attribut' => 'valeur de l\'attribut', # NEW
'zxml_vide_balise' => 'balise vide', # NEW
'zxml_vu' => 'vu auparavant', # NE
);

?>
